# SharedMemory

Encapsulation of the python shared_memory library.

### Features
* Sharing:
    * Basic type (int, float, bool, str)
    * list and dict
* Adding Mutex
* Adding timeout for Mutex
* Adding method to check data avability trough the shared memory
* Adding method to get access to data availability information

### Future improvement
* Adding more tests

### More
[![PyPI version](https://badge.fury.io/py/SharedMemory.svg)](https://badge.fury.io/py/SharedMemory)
[![Python 3.8](https://img.shields.io/badge/python-3.8-blue.svg)](https://www.python.org/downloads/release/python-380/)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)
![Python package](https://github.com/Zentetsu/SharedMemory/workflows/Python%20package/badge.svg?branch=master)
![Upload Python Package](https://github.com/Zentetsu/SharedMemory/workflows/Upload%20Python%20Package/badge.svg)
